Skip to main content Crate assay_workflow Copy item path Source pub use ctx::EngineEvent ;pub use ctx::WorkflowCtx ;pub use store::postgres::PostgresStore ;pub use store::sqlite::SqliteStore ;activities Activity operations and side effects. api archival Optional background archival of completed workflows to S3. auth_mode Auth configuration types — AuthMode, JwtConfig, JwksCache.
Lives at crate root (not under api/) so ctx.rs can import
AuthMode without creating a dependency cycle with api/auth.rs. children Child workflow operations and continue-as-new. ctx dispatch_recovery Background task that recovers workflow tasks whose worker has died. health lifecycle Workflow lifecycle methods: start, get, list, cancel, terminate, complete, fail,
finalise_cancellation, upsert_search_attributes, notify_parent_of_child_outcome. namespaces Namespace CRUD + snapshot methods. scheduler schedules Schedule CRUD methods. signals Signal and event-history methods. state store Backend implementations of WorkflowStore. tasks Workflow-task dispatch and timers. timers types Shared type definitions re-exported at the crate root. workers Worker registry methods. WorkflowStore Core storage trait for the workflow engine.